"use strict";(self.webpackChunkexample_feast_ui=self.webpackChunkexample_feast_ui||[]).push([[44421],{8228:(e,t,n)=>{n.r(t),n.d(t,{icon:()=>a});n(65043);var r=n(77724),l=["title","titleId"];function i(){return i=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},i.apply(null,arguments)}var a=function(e){var t=e.title,n=e.titleId,a=function(e,t){if(null==e)return{};var n,r,l=function(e,t){if(null==e)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)>=0)continue;n[r]=e[r]}return n}(e,t);if(Object.getOwnPropertySymbols){var i=Object.getOwnPropertySymbols(e);for(r=0;r<i.length;r++)n=i[r],t.indexOf(n)>=0||{}.propertyIsEnumerable.call(e,n)&&(l[n]=e[n])}return l}(e,l);return(0,r.Y)("svg",i({xmlns:"http://www.w3.org/2000/svg",width:32,height:32,viewBox:"0 0 32 32","aria-labelledby":n},a),t?(0,r.Y)("title",{id:n},t):null,(0,r.Y)("g",{fill:"none"},(0,r.Y)("path",{fill:"#C4373A",d:"M0 31.806h32V.776H0z"}),(0,r.Y)("path",{fill:"#FFF",d:"m19.448 12.508-8.986 3.86 8.986 3.883v-7.743Zm-11.304 4.73-2.094-.863 2.094-.931 17.749-7.741v2.062l-4.654 1.99v9.25l4.654 2.01v1.968L8.143 17.24Z"})))}}}]);
//# sourceMappingURL=icon.logo_aerospike.a09cc17e.chunk.js.map