"use strict";(self.webpackChunkexample_feast_ui=self.webpackChunkexample_feast_ui||[]).push([[40666],{36145:(e,t,r)=>{r.r(t),r.d(t,{icon:()=>a});r(65043);var n=r(77724),l=["title","titleId"];function i(){return i=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var r=arguments[t];for(var n in r)({}).hasOwnProperty.call(r,n)&&(e[n]=r[n])}return e},i.apply(null,arguments)}var a=function(e){var t=e.title,r=e.titleId,a=function(e,t){if(null==e)return{};var r,n,l=function(e,t){if(null==e)return{};var r={};for(var n in e)if({}.hasOwnProperty.call(e,n)){if(t.indexOf(n)>=0)continue;r[n]=e[n]}return r}(e,t);if(Object.getOwnPropertySymbols){var i=Object.getOwnPropertySymbols(e);for(n=0;n<i.length;n++)r=i[n],t.indexOf(r)>=0||{}.propertyIsEnumerable.call(e,r)&&(l[r]=e[r])}return l}(e,l);return(0,n.Y)("svg",i({xmlns:"http://www.w3.org/2000/svg",width:32,height:32,viewBox:"0 0 32 32","aria-labelledby":r},a),t?(0,n.Y)("title",{id:r},t):null,(0,n.Y)("path",{d:"M14.738 28.044V16.681L3.172 10.919v6.46l5.32 2.67v4.889l6.246 3.106Zm2.344.066 6.357-3.17v-5.002l5.353-2.686V10.87l-11.71 5.854V28.11ZM27.306 8.993l-6.003-3.012-5.286 2.656-5.325-2.659L4.637 9.03l11.317 5.638 11.352-5.675ZM.828 23.744V8.324L15.981.689l15.155 7.604V23.72L15.98 31.28.828 23.743Z"}))}}}]);
//# sourceMappingURL=icon.logo_codesandbox.29a07167.chunk.js.map